==> openshift-model-operator-6.9.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/UpstreamResolversFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class UpstreamResolversFluent<A extends UpstreamResolversFluent<A>> extends BaseFluent<A>{
  public UpstreamResolversFluent() {
  }
  
  public UpstreamResolversFluent(UpstreamResolvers instance) {
    this.copyInstance(instance);
  }
  private String policy;
  private String protocolStrategy;
  private DNSTransportConfigBuilder transportConfig;
  private ArrayList<UpstreamBuilder> upstreams = new ArrayList<UpstreamBuilder>();
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(UpstreamResolvers instance) {
    instance = (instance != null ? instance : new UpstreamResolvers());
  
    if (instance != null) {
        this.withPolicy(instance.getPolicy());
        this.withProtocolStrategy(instance.getProtocolStrategy());
        this.withTransportConfig(instance.getTransportConfig());
        this.withUpstreams(instance.getUpstreams());
        this.withPolicy(instance.getPolicy());
        this.withProtocolStrategy(instance.getProtocolStrategy());
        this.withTransportConfig(instance.getTransportConfig());
        this.withUpstreams(instance.getUpstreams());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getPolicy() {
    return this.policy;
  }
  
  public A withPolicy(String policy) {
    this.policy=policy; return (A) this;
  }
  
  public boolean hasPolicy() {
    return this.policy != null;
  }
  
  public String getProtocolStrategy() {
    return this.protocolStrategy;
  }
  
  public A withProtocolStrategy(String protocolStrategy) {
    this.protocolStrategy=protocolStrategy; return (A) this;
  }
  
  public boolean hasProtocolStrategy() {
    return this.protocolStrategy != null;
  }
  
  public DNSTransportConfig buildTransportConfig() {
    return this.transportConfig!=null ?this.transportConfig.build():null;
  }
  
  public A withTransportConfig(DNSTransportConfig transportConfig) {
    _visitables.get("transportConfig").remove(this.transportConfig);
    if (transportConfig!=null){ this.transportConfig= new DNSTransportConfigBuilder(transportConfig); _visitables.get("transportConfig").add(this.transportConfig);} else { this.transportConfig = null; _visitables.get("transportConfig").remove(this.transportConfig); } return (A) this;
  }
  
  public boolean hasTransportConfig() {
    return this.transportConfig != null;
  }
  
  public TransportConfigNested<A> withNewTransportConfig() {
    return new TransportConfigNested(null);
  }
  
  public TransportConfigNested<A> withNewTransportConfigLike(DNSTransportConfig item) {
    return new TransportConfigNested(item);
  }
  
  public TransportConfigNested<A> editTransportConfig() {
    return withNewTransportConfigLike(java.util.Optional.ofNullable(buildTransportConfig()).orElse(null));
  }
  
  public TransportConfigNested<A> editOrNewTransportConfig() {
    return withNewTransportConfigLike(java.util.Optional.ofNullable(buildTransportConfig()).orElse(new DNSTransportConfigBuilder().build()));
  }
  
  public TransportConfigNested<A> editOrNewTransportConfigLike(DNSTransportConfig item) {
    return withNewTransportConfigLike(java.util.Optional.ofNullable(buildTransportConfig()).orElse(item));
  }
  
  public A addToUpstreams(int index,Upstream item) {
    if (this.upstreams == null) {this.upstreams = new ArrayList<UpstreamBuilder>();}
    UpstreamBuilder builder = new UpstreamBuilder(item);
    if (index < 0 || index >= upstreams.size()) { _visitables.get("upstreams").add(builder); upstreams.add(builder); } else { _visitables.get("upstreams").add(index, builder); upstreams.add(index, builder);}
    return (A)this;
  }
  
  public A setToUpstreams(int index,Upstream item) {
    if (this.upstreams == null) {this.upstreams = new ArrayList<UpstreamBuilder>();}
    UpstreamBuilder builder = new UpstreamBuilder(item);
    if (index < 0 || index >= upstreams.size()) { _visitables.get("upstreams").add(builder); upstreams.add(builder); } else { _visitables.get("upstreams").set(index, builder); upstreams.set(index, builder);}
    return (A)this;
  }
  
  public A addToUpstreams(io.fabric8.openshift.api.model.operator.v1.Upstream... items) {
    if (this.upstreams == null) {this.upstreams = new ArrayList<UpstreamBuilder>();}
    for (Upstream item : items) {UpstreamBuilder builder = new UpstreamBuilder(item);_visitables.get("upstreams").add(builder);this.upstreams.add(builder);} return (A)this;
  }
  
  public A addAllToUpstreams(Collection<Upstream> items) {
    if (this.upstreams == null) {this.upstreams = new ArrayList<UpstreamBuilder>();}
    for (Upstream item : items) {UpstreamBuilder builder = new UpstreamBuilder(item);_visitables.get("upstreams").add(builder);this.upstreams.add(builder);} return (A)this;
  }
  
  public A removeFromUpstreams(io.fabric8.openshift.api.model.operator.v1.Upstream... items) {
    if (this.upstreams == null) return (A)this;
    for (Upstream item : items) {UpstreamBuilder builder = new UpstreamBuilder(item);_visitables.get("upstreams").remove(builder); this.upstreams.remove(builder);} return (A)this;
  }
  
  public A removeAllFromUpstreams(Collection<Upstream> items) {
    if (this.upstreams == null) return (A)this;
    for (Upstream item : items) {UpstreamBuilder builder = new UpstreamBuilder(item);_visitables.get("upstreams").remove(builder); this.upstreams.remove(builder);} return (A)this;
  }
  
  public A removeMatchingFromUpstreams(Predicate<UpstreamBuilder> predicate) {
    if (upstreams == null) return (A) this;
    final Iterator<UpstreamBuilder> each = upstreams.iterator();
    final List visitables = _visitables.get("upstreams");
    while (each.hasNext()) {
      UpstreamBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  public List<Upstream> buildUpstreams() {
    return upstreams != null ? build(upstreams) : null;
  }
  
  public Upstream buildUpstream(int index) {
    return this.upstreams.get(index).build();
  }
  
  public Upstream buildFirstUpstream() {
    return this.upstreams.get(0).build();
  }
  
  public Upstream buildLastUpstream() {
    return this.upstreams.get(upstreams.size() - 1).build();
  }
  
  public Upstream buildMatchingUpstream(Predicate<UpstreamBuilder> predicate) {
    for (UpstreamBuilder item: upstreams) { if(predicate.test(item)){ return item.build();} } return null;
  }
  
  public boolean hasMatchingUpstream(Predicate<UpstreamBuilder> predicate) {
    for (UpstreamBuilder item: upstreams) { if(predicate.test(item)){ return true;} } return false;
  }
  
  public A withUpstreams(List<Upstream> upstreams) {
    if (this.upstreams != null) { _visitables.get("upstreams").clear();}
    if (upstreams != null) {this.upstreams = new ArrayList(); for (Upstream item : upstreams){this.addToUpstreams(item);}} else { this.upstreams = null;} return (A) this;
  }
  
  public A withUpstreams(io.fabric8.openshift.api.model.operator.v1.Upstream... upstreams) {
    if (this.upstreams != null) {this.upstreams.clear(); _visitables.remove("upstreams"); }
    if (upstreams != null) {for (Upstream item :upstreams){ this.addToUpstreams(item);}} return (A) this;
  }
  
  public boolean hasUpstreams() {
    return upstreams != null && !upstreams.isEmpty();
  }
  
  public A addNewUpstream(String address,Integer port,String type) {
    return (A)addToUpstreams(new Upstream(address, port, type));
  }
  
  public UpstreamsNested<A> addNewUpstream() {
    return new UpstreamsNested(-1, null);
  }
  
  public UpstreamsNested<A> addNewUpstreamLike(Upstream item) {
    return new UpstreamsNested(-1, item);
  }
  
  public UpstreamsNested<A> setNewUpstreamLike(int index,Upstream item) {
    return new UpstreamsNested(index, item);
  }
  
  public UpstreamsNested<A> editUpstream(int index) {
    if (upstreams.size() <= index) throw new RuntimeException("Can't edit upstreams. Index exceeds size.");
    return setNewUpstreamLike(index, buildUpstream(index));
  }
  
  public UpstreamsNested<A> editFirstUpstream() {
    if (upstreams.size() == 0) throw new RuntimeException("Can't edit first upstreams. The list is empty.");
    return setNewUpstreamLike(0, buildUpstream(0));
  }
  
  public UpstreamsNested<A> editLastUpstream() {
    int index = upstreams.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last upstreams. The list is empty.");
    return setNewUpstreamLike(index, buildUpstream(index));
  }
  
  public UpstreamsNested<A> editMatchingUpstream(Predicate<UpstreamBuilder> predicate) {
    int index = -1;
    for (int i=0;i<upstreams.size();i++) { 
    if (predicate.test(upstreams.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching upstreams. No match found.");
    return setNewUpstreamLike(index, buildUpstream(index));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    UpstreamResolversFluent that = (UpstreamResolversFluent) o;
    if (!java.util.Objects.equals(policy, that.policy)) return false;
  
    if (!java.util.Objects.equals(protocolStrategy, that.protocolStrategy)) return false;
  
    if (!java.util.Objects.equals(transportConfig, that.transportConfig)) return false;
  
    if (!java.util.Objects.equals(upstreams, that.upstreams)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(policy,  protocolStrategy,  transportConfig,  upstreams,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (policy != null) { sb.append("policy:"); sb.append(policy + ","); }
    if (protocolStrategy != null) { sb.append("protocolStrategy:"); sb.append(protocolStrategy + ","); }
    if (transportConfig != null) { sb.append("transportConfig:"); sb.append(transportConfig + ","); }
    if (upstreams != null && !upstreams.isEmpty()) { sb.append("upstreams:"); sb.append(upstreams + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class TransportConfigNested<N> extends DNSTransportConfigFluent<TransportConfigNested<N>> implements Nested<N>{
    TransportConfigNested(DNSTransportConfig item) {
      this.builder = new DNSTransportConfigBuilder(this, item);
    }
    DNSTransportConfigBuilder builder;
    
    public N and() {
      return (N) UpstreamResolversFluent.this.withTransportConfig(builder.build());
    }
    
    public N endTransportConfig() {
      return and();
    }
    
  
  }
  public class UpstreamsNested<N> extends UpstreamFluent<UpstreamsNested<N>> implements Nested<N>{
    UpstreamsNested(int index,Upstream item) {
      this.index = index;
      this.builder = new UpstreamBuilder(this, item);
    }
    UpstreamBuilder builder;
    int index;
    
    public N and() {
      return (N) UpstreamResolversFluent.this.setToUpstreams(index,builder.build());
    }
    
    public N endUpstream() {
      return and();
    }
    
  
  }

}

==> openshift-model-operator-6.9.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/UpstreamResolversFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class UpstreamResolversFluent<A extends UpstreamResolversFluent<A>> extends BaseFluent<A>{
  public UpstreamResolversFluent() {
  }
  
  public UpstreamResolversFluent(UpstreamResolvers instance) {
    this.copyInstance(instance);
  }
  private String policy;
  private String protocolStrategy;
  private DNSTransportConfigBuilder transportConfig;
  private ArrayList<UpstreamBuilder> upstreams = new ArrayList<UpstreamBuilder>();
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(UpstreamResolvers instance) {
    instance = (instance != null ? instance : new UpstreamResolvers());
    if (instance != null) {
          this.withPolicy(instance.getPolicy());
          this.withProtocolStrategy(instance.getProtocolStrategy());
          this.withTransportConfig(instance.getTransportConfig());
          this.withUpstreams(instance.getUpstreams());
          this.withPolicy(instance.getPolicy());
          this.withProtocolStrategy(instance.getProtocolStrategy());
          this.withTransportConfig(instance.getTransportConfig());
          this.withUpstreams(instance.getUpstreams());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getPolicy() {
    return this.policy;
  }
  
  public A withPolicy(String policy) {
    this.policy = policy;
    return (A) this;
  }
  
  public boolean hasPolicy() {
    return this.policy != null;
  }
  
  public String getProtocolStrategy() {
    return this.protocolStrategy;
  }
  
  public A withProtocolStrategy(String protocolStrategy) {
    this.protocolStrategy = protocolStrategy;
    return (A) this;
  }
  
  public boolean hasProtocolStrategy() {
    return this.protocolStrategy != null;
  }
  
  public DNSTransportConfig buildTransportConfig() {
    return this.transportConfig != null ? this.transportConfig.build() : null;
  }
  
  public A withTransportConfig(DNSTransportConfig transportConfig) {
    this._visitables.remove(this.transportConfig);
    if (transportConfig != null) {
        this.transportConfig = new DNSTransportConfigBuilder(transportConfig);
        this._visitables.get("transportConfig").add(this.transportConfig);
    } else {
        this.transportConfig = null;
        this._visitables.get("transportConfig").remove(this.transportConfig);
    }
    return (A) this;
  }
  
  public boolean hasTransportConfig() {
    return this.transportConfig != null;
  }
  
  public TransportConfigNested<A> withNewTransportConfig() {
    return new TransportConfigNested(null);
  }
  
  public TransportConfigNested<A> withNewTransportConfigLike(DNSTransportConfig item) {
    return new TransportConfigNested(item);
  }
  
  public TransportConfigNested<A> editTransportConfig() {
    return withNewTransportConfigLike(java.util.Optional.ofNullable(buildTransportConfig()).orElse(null));
  }
  
  public TransportConfigNested<A> editOrNewTransportConfig() {
    return withNewTransportConfigLike(java.util.Optional.ofNullable(buildTransportConfig()).orElse(new DNSTransportConfigBuilder().build()));
  }
  
  public TransportConfigNested<A> editOrNewTransportConfigLike(DNSTransportConfig item) {
    return withNewTransportConfigLike(java.util.Optional.ofNullable(buildTransportConfig()).orElse(item));
  }
  
  public A addToUpstreams(int index,Upstream item) {
    if (this.upstreams == null) {this.upstreams = new ArrayList<UpstreamBuilder>();}
    UpstreamBuilder builder = new UpstreamBuilder(item);
    if (index < 0 || index >= upstreams.size()) { _visitables.get("upstreams").add(builder); upstreams.add(builder); } else { _visitables.get("upstreams").add(index, builder); upstreams.add(index, builder);}
    return (A)this;
  }
  
  public A setToUpstreams(int index,Upstream item) {
    if (this.upstreams == null) {this.upstreams = new ArrayList<UpstreamBuilder>();}
    UpstreamBuilder builder = new UpstreamBuilder(item);
    if (index < 0 || index >= upstreams.size()) { _visitables.get("upstreams").add(builder); upstreams.add(builder); } else { _visitables.get("upstreams").set(index, builder); upstreams.set(index, builder);}
    return (A)this;
  }
  
  public A addToUpstreams(io.fabric8.openshift.api.model.operator.v1.Upstream... items) {
    if (this.upstreams == null) {this.upstreams = new ArrayList<UpstreamBuilder>();}
    for (Upstream item : items) {UpstreamBuilder builder = new UpstreamBuilder(item);_visitables.get("upstreams").add(builder);this.upstreams.add(builder);} return (A)this;
  }
  
  public A addAllToUpstreams(Collection<Upstream> items) {
    if (this.upstreams == null) {this.upstreams = new ArrayList<UpstreamBuilder>();}
    for (Upstream item : items) {UpstreamBuilder builder = new UpstreamBuilder(item);_visitables.get("upstreams").add(builder);this.upstreams.add(builder);} return (A)this;
  }
  
  public A removeFromUpstreams(io.fabric8.openshift.api.model.operator.v1.Upstream... items) {
    if (this.upstreams == null) return (A)this;
    for (Upstream item : items) {UpstreamBuilder builder = new UpstreamBuilder(item);_visitables.get("upstreams").remove(builder); this.upstreams.remove(builder);} return (A)this;
  }
  
  public A removeAllFromUpstreams(Collection<Upstream> items) {
    if (this.upstreams == null) return (A)this;
    for (Upstream item : items) {UpstreamBuilder builder = new UpstreamBuilder(item);_visitables.get("upstreams").remove(builder); this.upstreams.remove(builder);} return (A)this;
  }
  
  public A removeMatchingFromUpstreams(Predicate<UpstreamBuilder> predicate) {
    if (upstreams == null) return (A) this;
    final Iterator<UpstreamBuilder> each = upstreams.iterator();
    final List visitables = _visitables.get("upstreams");
    while (each.hasNext()) {
      UpstreamBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  public List<Upstream> buildUpstreams() {
    return this.upstreams != null ? build(upstreams) : null;
  }
  
  public Upstream buildUpstream(int index) {
    return this.upstreams.get(index).build();
  }
  
  public Upstream buildFirstUpstream() {
    return this.upstreams.get(0).build();
  }
  
  public Upstream buildLastUpstream() {
    return this.upstreams.get(upstreams.size() - 1).build();
  }
  
  public Upstream buildMatchingUpstream(Predicate<UpstreamBuilder> predicate) {
      for (UpstreamBuilder item : upstreams) {
        if (predicate.test(item)) {
          return item.build();
        }
      }
      return null;
  }
  
  public boolean hasMatchingUpstream(Predicate<UpstreamBuilder> predicate) {
      for (UpstreamBuilder item : upstreams) {
        if (predicate.test(item)) {
          return true;
        }
      }
      return false;
  }
  
  public A withUpstreams(List<Upstream> upstreams) {
    if (this.upstreams != null) {
      this._visitables.get("upstreams").clear();
    }
    if (upstreams != null) {
        this.upstreams = new ArrayList();
        for (Upstream item : upstreams) {
          this.addToUpstreams(item);
        }
    } else {
      this.upstreams = null;
    }
    return (A) this;
  }
  
  public A withUpstreams(io.fabric8.openshift.api.model.operator.v1.Upstream... upstreams) {
    if (this.upstreams != null) {this.upstreams.clear(); _visitables.remove("upstreams"); }
    if (upstreams != null) {for (Upstream item :upstreams){ this.addToUpstreams(item);}} return (A) this;
  }
  
  public boolean hasUpstreams() {
    return this.upstreams != null && !this.upstreams.isEmpty();
  }
  
  public A addNewUpstream(String address,Integer port,String type) {
    return (A)addToUpstreams(new Upstream(address, port, type));
  }
  
  public UpstreamsNested<A> addNewUpstream() {
    return new UpstreamsNested(-1, null);
  }
  
  public UpstreamsNested<A> addNewUpstreamLike(Upstream item) {
    return new UpstreamsNested(-1, item);
  }
  
  public UpstreamsNested<A> setNewUpstreamLike(int index,Upstream item) {
    return new UpstreamsNested(index, item);
  }
  
  public UpstreamsNested<A> editUpstream(int index) {
    if (upstreams.size() <= index) throw new RuntimeException("Can't edit upstreams. Index exceeds size.");
    return setNewUpstreamLike(index, buildUpstream(index));
  }
  
  public UpstreamsNested<A> editFirstUpstream() {
    if (upstreams.size() == 0) throw new RuntimeException("Can't edit first upstreams. The list is empty.");
    return setNewUpstreamLike(0, buildUpstream(0));
  }
  
  public UpstreamsNested<A> editLastUpstream() {
    int index = upstreams.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last upstreams. The list is empty.");
    return setNewUpstreamLike(index, buildUpstream(index));
  }
  
  public UpstreamsNested<A> editMatchingUpstream(Predicate<UpstreamBuilder> predicate) {
    int index = -1;
    for (int i=0;i<upstreams.size();i++) { 
    if (predicate.test(upstreams.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching upstreams. No match found.");
    return setNewUpstreamLike(index, buildUpstream(index));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    UpstreamResolversFluent that = (UpstreamResolversFluent) o;
    if (!java.util.Objects.equals(policy, that.policy)) return false;
    if (!java.util.Objects.equals(protocolStrategy, that.protocolStrategy)) return false;
    if (!java.util.Objects.equals(transportConfig, that.transportConfig)) return false;
    if (!java.util.Objects.equals(upstreams, that.upstreams)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(policy,  protocolStrategy,  transportConfig,  upstreams,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (policy != null) { sb.append("policy:"); sb.append(policy + ","); }
    if (protocolStrategy != null) { sb.append("protocolStrategy:"); sb.append(protocolStrategy + ","); }
    if (transportConfig != null) { sb.append("transportConfig:"); sb.append(transportConfig + ","); }
    if (upstreams != null && !upstreams.isEmpty()) { sb.append("upstreams:"); sb.append(upstreams + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class TransportConfigNested<N> extends DNSTransportConfigFluent<TransportConfigNested<N>> implements Nested<N>{
    TransportConfigNested(DNSTransportConfig item) {
      this.builder = new DNSTransportConfigBuilder(this, item);
    }
    DNSTransportConfigBuilder builder;
    
    public N and() {
      return (N) UpstreamResolversFluent.this.withTransportConfig(builder.build());
    }
    
    public N endTransportConfig() {
      return and();
    }
    
  
  }
  public class UpstreamsNested<N> extends UpstreamFluent<UpstreamsNested<N>> implements Nested<N>{
    UpstreamsNested(int index,Upstream item) {
      this.index = index;
      this.builder = new UpstreamBuilder(this, item);
    }
    UpstreamBuilder builder;
    int index;
    
    public N and() {
      return (N) UpstreamResolversFluent.this.setToUpstreams(index,builder.build());
    }
    
    public N endUpstream() {
      return and();
    }
    
  
  }

}
